@@ -1,16 +1,18 @@
 package App::BPOMUtils::RPO::Ingredients;
 
 use 5.010001;
+use locale;
 use strict;
 use warnings;
 use Log::ger;
 
 use Exporter 'import';
+use POSIX 'setlocale', 'LC_ALL';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-02-25'; # DATE
 our $DIST = 'App-BPOMUtils-RPO-Ingredients'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our @EXPORT_OK = qw(
                        bpom_rpo_ingredients_group_for_label
@@ -77,6 +79,11 @@ sub bpom_rpo_ingredients_group_for_label {
     my @rows;
     while (my $row = $csv->getline(\*STDIN)) { push @rows, $row }
 
+    if ($args{lang} eq 'ind') {
+        POSIX::setlocale(LC_ALL, "id_ID.UTF-8") or die "Can't set locale to id_ID.UTF-8";
+    } else {
+    }
+
     my %weights; # key = ingredient name, value = weight
     my %ingredients; # key = name, value = { weight=>, items=> }
     for my $n (1 .. $#rows) {
@@ -139,7 +146,7 @@ App::BPOMUtils::RPO::Ingredients - Group ingredients suitable for food label
 
 =head1 VERSION
 
-This document describes version 0.004 of App::BPOMUtils::RPO::Ingredients (from Perl distribution App-BPOMUtils-RPO-Ingredients), released on 2024-02-25.
+This document describes version 0.005 of App::BPOMUtils::RPO::Ingredients (from Perl distribution App-BPOMUtils-RPO-Ingredients), released on 2024-02-25.
 
 =head1 SYNOPSIS
 
